@@ -2,6 +2,7 @@ from django.db import models
 from edc_constants.choices import YES_NO, YES_NO_NA, YES_NO_UNKNOWN_NA
 from edc_constants.constants import NOT_APPLICABLE
 from edc_model import models as edc_models
+from edc_model.validators import date_not_future
 from edc_protocol.validators import date_not_before_study_start
 
 
@@ -9,7 +10,7 @@ class DeathReportModelMixin(models.Model):
 
     hospitalization_date = models.DateField(
         verbose_name="If YES, date of hospitalisation",
-        validators=[edc_models.date_not_future, date_not_before_study_start],
+        validators=[date_not_future, date_not_before_study_start],
         null=True,
         blank=True,
     )
@@ -45,7 +46,7 @@ class DeathReportModelMixin(models.Model):
 
     date_first_unwell = models.DateField(
         verbose_name="If YES, when did they first become unwell?",
-        validators=[edc_models.date_not_future, date_not_before_study_start],
+        validators=[date_not_future, date_not_before_study_start],
         null=True,
         blank=True,
     )
