@@ -8,7 +8,7 @@ from ...choices import INPATIENT_STATUSES
 
 class AeEffectModelMixin(models.Model):
 
-    fluconazole_relation = models.CharField(
+    flucon_relation = models.CharField(
         verbose_name="Relationship to study drugs: Fluconazole:",
         max_length=25,
         choices=[
@@ -16,7 +16,7 @@ class AeEffectModelMixin(models.Model):
         ],
     )
 
-    flucytosine_relation = models.CharField(
+    flucyt_relation = models.CharField(
         verbose_name="Relationship to study drugs: Flucytosine:",
         max_length=25,
         choices=STUDY_DRUG_RELATIONSHIP,
