@@ -31,16 +31,14 @@ class MedicalHistoryAdmin(CrfModelAdmin):
             "Other opportunistic infections",
             {"fields": ("previous_oi", "previous_oi_name", "previous_oi_dx_date")},
         ),
-        ("HIV diagnosis", {"fields": ("new_hiv_dx", "hiv_dx_date")}),
         audit_fieldset_tuple,
     )
 
     radio_fields = {
-        "new_hiv_dx": admin.VERTICAL,
-        "previous_oi": admin.VERTICAL,
         "on_rifampicin": admin.VERTICAL,
+        "on_tb_tx": admin.VERTICAL,
+        "previous_oi": admin.VERTICAL,
         "tb_dx_ago": admin.VERTICAL,
         "tb_prev_dx": admin.VERTICAL,
         "tb_site": admin.VERTICAL,
-        "on_tb_tx": admin.VERTICAL,
     }
