@@ -1,14 +1,21 @@
-from django.test import TestCase, tag
+from typing import Optional
+
+from django.test import TestCase
 from edc_constants.constants import NO, NOT_APPLICABLE, NOT_ESTIMATED, OTHER, YES
+from edc_test_utils.validate_fields_exists_or_raise import (
+    validate_fields_exists_or_raise,
+)
+from edc_utils import get_utcnow_as_date
+from edc_visit_schedule.constants import DAY01
 from model_bakery import baker
 
 from effect_lists.models import Antibiotics, Drugs, TbTreatments
 from effect_screening.tests.effect_test_case_mixin import EffectTestCaseMixin
 from effect_subject.forms import PatientTreatmentForm
 from effect_subject.forms.patient_treatment_form import PatientTreatmentFormValidator
+from effect_subject.models import PatientTreatment, SubjectVisit
 
 
-@tag("pt")
 class TestPatientTreatment(EffectTestCaseMixin, TestCase):
     def setUp(self):
         super().setUp()
@@ -23,19 +30,24 @@ class TestPatientTreatment(EffectTestCaseMixin, TestCase):
         form.is_valid()
 
 
-@tag("pt")
 class TestPatientTreatmentFormValidation(EffectTestCaseMixin, TestCase):
 
     form_validator_default_form_cls = PatientTreatmentFormValidator
 
-    def setUp(self):
+    def setUp(self) -> None:
         super().setUp()
-        self.subject_visit = self.get_subject_visit()
+        subject_visit = self.get_subject_visit()
+        subject_visit = self.get_next_subject_visit(subject_visit)
+        subject_visit = self.get_next_subject_visit(subject_visit)
+        self.get_next_subject_visit(subject_visit)
 
-    def get_cleaned_data_patient_no_cm_no_tx(self):
-        return {
-            "appointment": self.subject_visit.appointment,
-            "report_datetime": self.subject_visit.report_datetime,
+    @staticmethod
+    def get_cleaned_data_patient_no_cm_no_tx(visit_code: Optional[str] = None):
+        visit_code = visit_code or DAY01
+        subject_visit = SubjectVisit.objects.get(visit_code=visit_code)
+        cleaned_data = {
+            "subject_visit": subject_visit,
+            "report_datetime": subject_visit.report_datetime,
             "lp_completed": NO,
             "cm_confirmed": NOT_APPLICABLE,
             "on_cm_tx": NOT_APPLICABLE,
@@ -71,59 +83,70 @@ class TestPatientTreatmentFormValidation(EffectTestCaseMixin, TestCase):
             "other_drugs_given_other": "",
         }
 
-    def get_cleaned_data_patient_with_cm_with_all_tx(self):
-        return {
-            "appointment": self.subject_visit.appointment,
-            "report_datetime": self.subject_visit.report_datetime,
+        validate_fields_exists_or_raise(cleaned_data, PatientTreatment)
+
+        return cleaned_data
+
+    @staticmethod
+    def get_cleaned_data_patient_with_cm_with_all_tx(visit_code: Optional[str] = None):
+        visit_code = visit_code or DAY01
+        subject_visit = SubjectVisit.objects.get(visit_code=visit_code)
+        cleaned_data = {
+            "subject_visit": subject_visit,
+            "report_datetime": subject_visit.report_datetime,
             "lp_completed": YES,
             "cm_confirmed": YES,
             "on_cm_tx": YES,
             "cm_tx_given": "1w_amb_5fc",
             "cm_tx_given_other": "",
             "on_tb_tx": YES,
-            "tb_tx_date": self.get_utcnow_as_date(),
+            "tb_tx_date": get_utcnow_as_date(),
             "tb_tx_date_estimated": NOT_ESTIMATED,
             "tb_tx_given": TbTreatments.objects.filter(name="H"),
             "tb_tx_given_other": "",
             "tb_tx_reason_no": NOT_APPLICABLE,
             "tb_tx_reason_no_other": "",
             "on_steroids": YES,
-            "steroids_date": self.get_utcnow_as_date(),
+            "steroids_date": get_utcnow_as_date(),
             "steroids_date_estimated": NOT_ESTIMATED,
             "steroids_given": "oral_prednisolone",
             "steroids_given_other": "",
             "steroids_course": 3,
             "on_co_trimoxazole": YES,
-            "co_trimoxazole_date": self.get_utcnow_as_date(),
+            "co_trimoxazole_date": get_utcnow_as_date(),
             "co_trimoxazole_date_estimated": NOT_ESTIMATED,
             "co_trimoxazole_reason_no": NOT_APPLICABLE,
             "co_trimoxazole_reason_no_other": "",
             "on_antibiotics": YES,
-            "antibiotics_date": self.get_utcnow_as_date(),
+            "antibiotics_date": get_utcnow_as_date(),
             "antibiotics_date_estimated": NOT_ESTIMATED,
             "antibiotics_given": Antibiotics.objects.filter(name="amoxicillin"),
             "antibiotics_given_other": "",
             "on_other_drugs": YES,
-            "other_drugs_date": self.get_utcnow_as_date(),
+            "other_drugs_date": get_utcnow_as_date(),
             "other_drugs_date_estimated": NOT_ESTIMATED,
             "other_drugs_given": Drugs.objects.filter(name="vitamins"),
             "other_drugs_given_other": "",
         }
 
+        validate_fields_exists_or_raise(cleaned_data, PatientTreatment)
+
+        return cleaned_data
+
     def test_cleaned_data_patient_no_cm_no_tx_ok(self):
-        cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx()
+        cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx(visit_code=DAY01)
         self.assertFormValidatorNoError(
             form_validator=self.validate_form_validator(cleaned_data)
         )
 
     def test_cleaned_data_patient_with_cm_with_all_tx_ok(self):
-        cleaned_data = self.get_cleaned_data_patient_with_cm_with_all_tx()
+        cleaned_data = self.get_cleaned_data_patient_with_cm_with_all_tx(visit_code=DAY01)
         self.assertFormValidatorNoError(
             form_validator=self.validate_form_validator(cleaned_data)
         )
 
     def test_cm_confirmed_na_if_lp_not_completed(self):
-        cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx()
+        cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx(visit_code=DAY01)
         cleaned_data.update(
             {
                 "lp_completed": NO,
@@ -137,7 +160,7 @@ class TestPatientTreatmentFormValidation(EffectTestCaseMixin, TestCase):
         )
 
     def test_cm_confirmed_applicable_if_lp_completed(self):
-        cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx()
+        cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx(visit_code=DAY01)
         cleaned_data.update(
             {
                 "lp_completed": YES,
@@ -151,7 +174,7 @@ class TestPatientTreatmentFormValidation(EffectTestCaseMixin, TestCase):
         )
 
     def test_cm_tx_na_if_cm_not_confirmed(self):
-        cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx()
+        cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx(visit_code=DAY01)
         cleaned_data.update(
             {
                 "lp_completed": YES,
@@ -166,7 +189,7 @@ class TestPatientTreatmentFormValidation(EffectTestCaseMixin, TestCase):
         )
 
     def test_cm_tx_applicable_if_cm_confirmed(self):
-        cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx()
+        cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx(visit_code=DAY01)
         cleaned_data.update(
             {
                 "lp_completed": YES,
@@ -181,7 +204,7 @@ class TestPatientTreatmentFormValidation(EffectTestCaseMixin, TestCase):
         )
 
     def test_cm_tx_given_na_if_cm_tx_no(self):
-        cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx()
+        cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx(visit_code=DAY01)
         cleaned_data.update(
             {
                 "lp_completed": YES,
@@ -197,7 +220,7 @@ class TestPatientTreatmentFormValidation(EffectTestCaseMixin, TestCase):
         )
 
     def test_cm_tx_given_applicable_if_cm_tx(self):
-        cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx()
+        cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx(visit_code=DAY01)
         cleaned_data.update(
             {
                 "lp_completed": YES,
@@ -213,7 +236,7 @@ class TestPatientTreatmentFormValidation(EffectTestCaseMixin, TestCase):
         )
 
     def test_cm_tx_given_other_required_if_specified(self):
-        cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx()
+        cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx(visit_code=DAY01)
         cleaned_data.update(
             {
                 "lp_completed": YES,
@@ -230,7 +253,7 @@ class TestPatientTreatmentFormValidation(EffectTestCaseMixin, TestCase):
         )
 
     def test_cm_tx_given_other_not_required_if_not_specified(self):
-        cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx()
+        cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx(visit_code=DAY01)
         cleaned_data.update(
             {
                 "lp_completed": YES,
@@ -248,7 +271,7 @@ class TestPatientTreatmentFormValidation(EffectTestCaseMixin, TestCase):
 
     # steroid validation tests
     def test_steroids_given_na_if_steroids_no(self):
-        cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx()
+        cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx(visit_code=DAY01)
         cleaned_data.update(
             {
                 "on_steroids": NO,
@@ -264,11 +287,11 @@ class TestPatientTreatmentFormValidation(EffectTestCaseMixin, TestCase):
         )
 
     def test_steroids_given_applicable_if_steroids(self):
-        cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx()
+        cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx(visit_code=DAY01)
         cleaned_data.update(
             {
                 "on_steroids": YES,
-                "steroids_date": self.get_utcnow_as_date(),
+                "steroids_date": get_utcnow_as_date(),
                 "steroids_date_estimated": "MD",
                 "steroids_given": NOT_APPLICABLE,
                 "steroids_given_other": "",
@@ -282,11 +305,11 @@ class TestPatientTreatmentFormValidation(EffectTestCaseMixin, TestCase):
         )
 
     def test_steroids_given_other_required_if_specified(self):
-        cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx()
+        cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx(visit_code=DAY01)
         cleaned_data.update(
             {
                 "on_steroids": YES,
-                "steroids_date": self.get_utcnow_as_date(),
+                "steroids_date": get_utcnow_as_date(),
                 "steroids_date_estimated": "MD",
                 "steroids_given": OTHER,
                 "steroids_given_other": "",
@@ -300,11 +323,11 @@ class TestPatientTreatmentFormValidation(EffectTestCaseMixin, TestCase):
         )
 
     def test_steroids_given_other_not_required_if_not_specified(self):
-        cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx()
+        cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx(visit_code=DAY01)
         cleaned_data.update(
             {
                 "on_steroids": YES,
-                "steroids_date": self.get_utcnow_as_date(),
+                "steroids_date": get_utcnow_as_date(),
                 "steroids_date_estimated": "MD",
                 "steroids_given": "oral_prednisolone",
                 "steroids_given_other": "xxx",
@@ -318,7 +341,7 @@ class TestPatientTreatmentFormValidation(EffectTestCaseMixin, TestCase):
         )
 
     def test_steroids_course_not_required_if_steroids_no(self):
-        cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx()
+        cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx(visit_code=DAY01)
         cleaned_data.update(
             {
                 "on_steroids": NO,
@@ -334,11 +357,11 @@ class TestPatientTreatmentFormValidation(EffectTestCaseMixin, TestCase):
         )
 
     def test_steroids_course_required_if_steroids(self):
-        cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx()
+        cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx(visit_code=DAY01)
         cleaned_data.update(
             {
                 "on_steroids": YES,
-                "steroids_date": self.get_utcnow_as_date(),
+                "steroids_date": get_utcnow_as_date(),
                 "steroids_date_estimated": "MD",
                 "steroids_given": "oral_prednisolone",
                 "steroids_given_other": "",
@@ -360,7 +383,7 @@ class TestPatientTreatmentFormValidation(EffectTestCaseMixin, TestCase):
             "other_drugs",
         ]:
             with self.subTest(field_stub=field_stub):
-                cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx()
+                cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx(visit_code=DAY01)
                 cleaned_data.update(
                     {
                         f"on_{field_stub}": YES,
@@ -382,11 +405,11 @@ class TestPatientTreatmentFormValidation(EffectTestCaseMixin, TestCase):
             "other_drugs",
         ]:
             with self.subTest(field_stub=field_stub):
-                cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx()
+                cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx(visit_code=DAY01)
                 cleaned_data.update(
                     {
                         f"on_{field_stub}": NO,
-                        f"{field_stub}_date": self.get_utcnow_as_date(),
+                        f"{field_stub}_date": get_utcnow_as_date(),
                     }
                 )
                 self.assertFormValidatorError(
@@ -404,11 +427,11 @@ class TestPatientTreatmentFormValidation(EffectTestCaseMixin, TestCase):
             "other_drugs",
         ]:
             with self.subTest(field_stub=field_stub):
-                cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx()
+                cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx(visit_code=DAY01)
                 cleaned_data.update(
                     {
                         f"on_{field_stub}": YES,
-                        f"{field_stub}_date": self.get_utcnow_as_date(),
+                        f"{field_stub}_date": get_utcnow_as_date(),
                         f"{field_stub}_date_estimated": NOT_APPLICABLE,
                     }
                 )
@@ -427,7 +450,7 @@ class TestPatientTreatmentFormValidation(EffectTestCaseMixin, TestCase):
             "other_drugs",
         ]:
             with self.subTest(field_stub=field_stub):
-                cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx()
+                cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx(visit_code=DAY01)
                 cleaned_data.update(
                     {
                         f"on_{field_stub}": NO,
@@ -448,11 +471,11 @@ class TestPatientTreatmentFormValidation(EffectTestCaseMixin, TestCase):
             ("other_drugs", Drugs),
         ]:
             with self.subTest(field_stub=field_stub, list_model=list_model):
-                cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx()
+                cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx(visit_code=DAY01)
                 cleaned_data.update(
                     {
                         f"on_{field_stub}": YES,
-                        f"{field_stub}_date": self.get_utcnow_as_date(),
+                        f"{field_stub}_date": get_utcnow_as_date(),
                         f"{field_stub}_date_estimated": "YMD",
                         f"{field_stub}_given": list_model.objects.none(),
                     }
@@ -470,7 +493,7 @@ class TestPatientTreatmentFormValidation(EffectTestCaseMixin, TestCase):
             ("other_drugs", Drugs),
         ]:
             with self.subTest(field_stub=field_stub, list_model=list_model):
-                cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx()
+                cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx(visit_code=DAY01)
                 cleaned_data.update(
                     {
                         f"on_{field_stub}": NO,
@@ -491,11 +514,11 @@ class TestPatientTreatmentFormValidation(EffectTestCaseMixin, TestCase):
             ("other_drugs", Drugs),
         ]:
             with self.subTest(field_stub=field_stub, list_model=list_model):
-                cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx()
+                cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx(visit_code=DAY01)
                 cleaned_data.update(
                     {
                         f"on_{field_stub}": YES,
-                        f"{field_stub}_date": self.get_utcnow_as_date(),
+                        f"{field_stub}_date": get_utcnow_as_date(),
                         f"{field_stub}_date_estimated": "YMD",
                         f"{field_stub}_given": list_model.objects.filter(name=OTHER),
                         f"{field_stub}_given_other": "",
@@ -521,7 +544,7 @@ class TestPatientTreatmentFormValidation(EffectTestCaseMixin, TestCase):
             ("other_drugs", Drugs),
         ]:
             with self.subTest(field_stub=field_stub, list_model=list_model):
-                cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx()
+                cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx(visit_code=DAY01)
                 cleaned_data.update(
                     {
                         f"on_{field_stub}": NO,
@@ -544,7 +567,7 @@ class TestPatientTreatmentFormValidation(EffectTestCaseMixin, TestCase):
     def test_reason_no_applicable_if_prescribed_no(self):
         for field_stub in ["tb_tx", "co_trimoxazole"]:
             with self.subTest(field_stub=field_stub):
-                cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx()
+                cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx(visit_code=DAY01)
                 cleaned_data.update({f"{field_stub}_reason_no": NOT_APPLICABLE})
                 self.assertFormValidatorError(
                     field=f"{field_stub}_reason_no",
@@ -555,11 +578,11 @@ class TestPatientTreatmentFormValidation(EffectTestCaseMixin, TestCase):
     def test_reason_no_not_applicable_if_prescribed_yes(self):
         for field_stub in ["tb_tx", "co_trimoxazole"]:
             with self.subTest(field_stub=field_stub):
-                cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx()
+                cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx(visit_code=DAY01)
                 cleaned_data.update(
                     {
                         f"on_{field_stub}": YES,
-                        f"{field_stub}_date": self.get_utcnow_as_date(),
+                        f"{field_stub}_date": get_utcnow_as_date(),
                         f"{field_stub}_date_estimated": "YMD",
                         f"{field_stub}_reason_no": "contraindicated",
                     }
@@ -576,7 +599,7 @@ class TestPatientTreatmentFormValidation(EffectTestCaseMixin, TestCase):
     def test_reason_no_other_required_if_specified(self):
         for field_stub in ["tb_tx", "co_trimoxazole"]:
             with self.subTest(field_stub=field_stub):
-                cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx()
+                cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx(visit_code=DAY01)
                 cleaned_data.update(
                     {
                         f"on_{field_stub}": NO,
@@ -593,7 +616,7 @@ class TestPatientTreatmentFormValidation(EffectTestCaseMixin, TestCase):
     def test_reason_no_other_not_required_if_not_specified(self):
         for field_stub in ["tb_tx", "co_trimoxazole"]:
             with self.subTest(field_stub=field_stub):
-                cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx()
+                cleaned_data = self.get_cleaned_data_patient_no_cm_no_tx(visit_code=DAY01)
                 cleaned_data.update(
                     {
                         f"on_{field_stub}": NO,
