@@ -1,8 +1,11 @@
 from copy import deepcopy
+from typing import Optional
 
 from django import forms
+from django.core.exceptions import ObjectDoesNotExist
 from django.db.models import Q
-from django.test import TestCase, tag
+from django.test import TestCase
+from edc_appointment.constants import IN_PROGRESS_APPT, INCOMPLETE_APPT
 from edc_constants.constants import (
     HEADACHE,
     IN_PERSON,
@@ -19,50 +22,54 @@ from edc_constants.disease_constants import (
     CN_PALSY_RIGHT_OTHER,
     FOCAL_NEUROLOGIC_DEFICIT_OTHER,
 )
+from edc_visit_tracking.constants import SCHEDULED
 from model_bakery import baker
 
 from effect_lists.models import SiSx
 from effect_screening.tests.effect_test_case_mixin import EffectTestCaseMixin
 from effect_subject.forms import SignsAndSymptomsForm
 from effect_subject.forms.signs_and_symptoms_form import SignsAndSymptomsFormValidator
+from effect_subject.models import SubjectVisit
 from effect_subject.tests.tests.mixins import ReportingFieldsetBaselineTestCaseMixin
 from effect_visit_schedule.constants import DAY01, DAY14
 
 # TODO: Migrate to effect-form-validator
 
 
-@tag("sas")
-class TestSignsAndSymptoms(EffectTestCaseMixin, TestCase):
-    def setUp(self):
-        super().setUp()
-        self.subject_visit = self.get_subject_visit()
+class SignsSymptomsTestError(Exception):
+    pass
 
+
+class TestSignsAndSymptoms(EffectTestCaseMixin, TestCase):
     def test_ok(self):
-        subject_visit = self.subject_visit
+        subject_visit = self.get_subject_visit()
         obj = baker.make_recipe("effect_subject.signsandsymptoms", subject_visit=subject_visit)
         form = SignsAndSymptomsForm(instance=obj)
         form.is_valid()
 
 
-@tag("sas")
 class TestSignsAndSymptomsFormValidationBase(EffectTestCaseMixin, TestCase):
 
     form_validator_default_form_cls = SignsAndSymptomsFormValidator
 
     def setUp(self):
         super().setUp()
-        self.subject_visit = self.get_subject_visit()
+        subject_visit = self.get_subject_visit()  # day01
+        subject_visit = self.get_next_subject_visit(subject_visit)  # day03
+        subject_visit = self.get_next_subject_visit(subject_visit)  # day09
+        self.get_next_subject_visit(subject_visit)  # day14
 
+    @staticmethod
     def get_valid_patient_with_no_signs_or_symptoms(
-        self,
         visit_code: str = None,
         assessment_type: str = None,
     ):
-        self.subject_visit.appointment.visit_code = visit_code or DAY14
-        self.subject_visit.assessment_type = assessment_type or IN_PERSON
+        visit_code = visit_code or DAY14
+        subject_visit = SubjectVisit.objects.get(visit_code=visit_code)
+        subject_visit.assessment_type = assessment_type or IN_PERSON
         return {
-            "subject_visit": self.subject_visit,
-            "report_datetime": self.subject_visit.report_datetime,
+            "subject_visit": subject_visit,
+            "report_datetime": subject_visit.report_datetime,
             "any_sx": NO,
             "current_sx": SiSx.objects.filter(name=NOT_APPLICABLE),
             "current_sx_other": "",
@@ -106,12 +113,42 @@ class TestSignsAndSymptomsFormValidationBase(EffectTestCaseMixin, TestCase):
         visit_code: str = None,
         assessment_type: str = None,
     ):
-        self.subject_visit.appointment.visit_code = visit_code or DAY14
-        self.subject_visit.assessment_type = assessment_type or IN_PERSON
+        visit_code = visit_code or DAY14
+        assessment_type = assessment_type or IN_PERSON
+        subject_visit = SubjectVisit.objects.get(visit_code=visit_code)
+        for v in subject_visit.schedule.visits.timepoints:
+            appointment = self.get_appointment(
+                subject_identifier=subject_visit.subject_identifier,
+                timepoint=v.timepoint,
+                visit_code_sequence=0,
+            )
+            try:
+                subject_visit = SubjectVisit.objects.get(appointment=appointment)
+            except ObjectDoesNotExist:
+                subject_visit = SubjectVisit.objects.create(
+                    appointment=appointment,
+                    reason=SCHEDULED,
+                    report_datetime=appointment.appt_datetime,
+                )
+            if v.name == visit_code:
+                appointment.appt_status = IN_PROGRESS_APPT
+                appointment.save()
+                appointment.refresh_from_db()
+                break
+            else:
+                appointment.appt_status = INCOMPLETE_APPT
+                appointment.save()
+                appointment.refresh_from_db()
+
+        if not subject_visit:
+            raise SignsSymptomsTestError("subject visit / appointment not found")
+        subject_visit.assessment_type = assessment_type
+        subject_visit.save()
+        subject_visit.refresh_from_db()
 
         return {
-            "subject_visit": self.subject_visit,
-            "report_datetime": self.subject_visit.report_datetime,
+            "subject_visit": subject_visit,
+            "report_datetime": subject_visit.report_datetime,
             "any_sx": YES,
             "current_sx": SiSx.objects.filter(Q(name="fever") | Q(name="vomiting")),
             "current_sx_other": "",
@@ -151,7 +188,6 @@ class TestSignsAndSymptomsFormValidationBase(EffectTestCaseMixin, TestCase):
         return cleaned_data
 
 
-@tag("sas")
 class TestSignsAndSymptomsFormValidation(TestSignsAndSymptomsFormValidationBase):
     def test_non_symptomatic_patient_valid_baseline(self):
         cleaned_data = self.get_valid_patient_with_no_signs_or_symptoms(visit_code=DAY01)
@@ -443,7 +479,8 @@ class TestSignsAndSymptomsFormValidation(TestSignsAndSymptomsFormValidationBase)
                     reportable_as_ae_answer=reportable_as_ae_answer,
                 ):
                     cleaned_data = self.get_valid_patient_with_no_signs_or_symptoms(
-                        assessment_type=TELEPHONE if any_sx_answer == UNKNOWN else IN_PERSON
+                        visit_code=DAY14,
+                        assessment_type=TELEPHONE if any_sx_answer == UNKNOWN else IN_PERSON,
                     )
                     cleaned_data.update(
                         {
@@ -872,14 +909,12 @@ class TestSignsAndSymptomsFormValidation(TestSignsAndSymptomsFormValidationBase)
                     )
 
 
-@tag("sas")
 class TestSignsAndSymptomsStatusReportingFieldsetFormValidation(
     ReportingFieldsetBaselineTestCaseMixin,
     TestSignsAndSymptomsFormValidationBase,
 ):
-    default_cleaned_data = (
-        TestSignsAndSymptomsFormValidationBase.get_valid_patient_with_signs_or_symptoms
-    )
+    def default_cleaned_data(self, visit_code: Optional[str] = None) -> dict:
+        return self.get_valid_patient_with_signs_or_symptoms(visit_code=visit_code)
 
     def test_reportable_as_ae_allowed_at_d14(self):
         cleaned_data = self.get_valid_patient_with_signs_or_symptoms(visit_code=DAY14)
@@ -889,9 +924,12 @@ class TestSignsAndSymptomsStatusReportingFieldsetFormValidation(
                 "current_sx_gte_g3": SiSx.objects.filter(name="fever"),
             }
         )
-        self.assertFormValidatorNoError(
-            form_validator=self.validate_form_validator(cleaned_data)
-        )
+
+        form_cls = self.form_validator_default_form_cls
+        form_validator = form_cls(cleaned_data=cleaned_data)
+        form_validator.validate()
+        self.assertDictEqual({}, form_validator._errors)
+
         cleaned_data.update(
             {
                 "reportable_as_ae": NO,
